=============
Display Group
=============

Display group commands are used to select a subset of the entities displayed in the viewport.


Create display groups
---------------------

.. autoclass:: abaqus.DisplayGroup.DisplayGroupSession.DisplayGroupSession
    :members:

    .. autoclasstoc::


Object features
---------------

DisplayGroup
~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.DisplayGroup.DisplayGroup
    :members:

    .. autoclasstoc::

DisplayGroupArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.DisplayGroupArray.DisplayGroupArray
    :members:

    .. autoclasstoc::

DisplayGroupInstance
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.DisplayGroupInstance.DisplayGroupInstance
    :members:

    .. autoclasstoc::

DisplayGroupInstanceRepository
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.DisplayGroupInstanceRepository.DisplayGroupInstanceRepository
    :members:

    .. autoclasstoc::

Leaf
~~~~

.. autoclass:: abaqus.DisplayGroup.Leaf.Leaf
    :members:

    .. autoclasstoc::

LeafFromDatums
~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromDatums.LeafFromDatums
    :members:

    .. autoclasstoc::

LeafFromDisplayGroup
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromDisplayGroup.LeafFromDisplayGroup
    :members:

    .. autoclasstoc::

LeafFromElementLabels
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromElementLabels.LeafFromElementLabels
    :members:

    .. autoclasstoc::

LeafFromElementSets
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromElementSets.LeafFromElementSets
    :members:

    .. autoclasstoc::

LeafFromElementVarRange
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromElementVarRange.LeafFromElementVarRange
    :members:

    .. autoclasstoc::

LeafFromGeometry
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromGeometry.LeafFromGeometry
    :members:

    .. autoclasstoc::

LeafFromInstance
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromInstance.LeafFromInstance
    :members:

    .. autoclasstoc::

LeafFromInstanceElementLabels
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromInstanceElementLabels.LeafFromInstanceElementLabels
    :members:

    .. autoclasstoc::

LeafFromInstanceNodeLabels
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromInstanceNodeLabels.LeafFromInstanceNodeLabels
    :members:

    .. autoclasstoc::

LeafFromMeshElementLabels
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromMeshElementLabels.LeafFromMeshElementLabels
    :members:

    .. autoclasstoc::

LeafFromMeshNodeLabels
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromMeshNodeLabels.LeafFromMeshNodeLabels
    :members:

    .. autoclasstoc::

LeafFromMeshSurfaceSets
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromMeshSurfaceSets.LeafFromMeshSurfaceSets
    :members:

    .. autoclasstoc::

LeafFromModelElemLabels
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromModelElemLabels.LeafFromModelElemLabels
    :members:

    .. autoclasstoc::

LeafFromModelNodeLabels
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromModelNodeLabels.LeafFromModelNodeLabels
    :members:

    .. autoclasstoc::

LeafFromNodeLabels
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromNodeLabels.LeafFromNodeLabels
    :members:

    .. autoclasstoc::

LeafFromNodeSets
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromNodeSets.LeafFromNodeSets
    :members:

    .. autoclasstoc::

LeafFromNodeVarRange
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromNodeVarRange.LeafFromNodeVarRange
    :members:

    .. autoclasstoc::

LeafFromOdbEdgePick
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbEdgePick.LeafFromOdbEdgePick
    :members:

    .. autoclasstoc::

LeafFromOdbElementLayups
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementLayups.LeafFromOdbElementLayups
    :members:

    .. autoclasstoc::

LeafFromOdbElementMaterials
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementMaterials.LeafFromOdbElementMaterials
    :members:

    .. autoclasstoc::

LeafFromOdbElementPick
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPick.LeafFromOdbElementPick
    :members:

    .. autoclasstoc::

LeafFromOdbElementPlies
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPlies.LeafFromOdbElementPlies
    :members:

    .. autoclasstoc::

LeafFromOdbElementSections
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementSections.LeafFromOdbElementSections
    :members:

    .. autoclasstoc::

LeafFromOdbElementTypes
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementTypes.LeafFromOdbElementTypes
    :members:

    .. autoclasstoc::

LeafFromOdbNodePick
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromOdbNodePick.LeafFromOdbNodePick
    :members:

    .. autoclasstoc::

LeafFromPartElementLabels
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromPartElementLabels.LeafFromPartElementLabels
    :members:

    .. autoclasstoc::

LeafFromPartInstance
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromPartInstance.LeafFromPartInstance
    :members:

    .. autoclasstoc::

LeafFromPartNodeLabels
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromPartNodeLabels.LeafFromPartNodeLabels
    :members:

    .. autoclasstoc::

LeafFromReferencePoint
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromReferencePoint.LeafFromReferencePoint
    :members:

    .. autoclasstoc::

LeafFromSets
~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromSets.LeafFromSets
    :members:

    .. autoclasstoc::

LeafFromSurfaceSets
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceSets.LeafFromSurfaceSets
    :members:

    .. autoclasstoc::

LeafFromSurfaceVarRange
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceVarRange.LeafFromSurfaceVarRange
    :members:
